@@ -101,6 +101,11 @@ GKeyFile *    ostree_repo_get_config (OstreeRepo *self);
 _OSTREE_PUBLIC
 GKeyFile *    ostree_repo_copy_config (OstreeRepo *self);
 
+_OSTREE_PUBLIC
+gboolean      ostree_repo_reload_config (OstreeRepo *self,
+                                         GCancellable *cancellable,
+                                         GError    **error);
+
 _OSTREE_PUBLIC
 gboolean      ostree_repo_remote_add (OstreeRepo     *self,
                                       const char     *name,
@@ -382,6 +387,22 @@ gboolean      ostree_repo_resolve_rev (OstreeRepo  *self,
                                        char       **out_rev,
                                        GError     **error);
 
+/**
+ * OstreeRepoResolveRevExtFlags:
+ * @OSTREE_REPO_RESOLVE_REV_EXT_NONE: No flags.
+ */
+typedef enum {
+  OSTREE_REPO_RESOLVE_REV_EXT_NONE = 0,
+} OstreeRepoResolveRevExtFlags;
+
+_OSTREE_PUBLIC
+gboolean      ostree_repo_resolve_rev_ext (OstreeRepo                    *self,
+                                           const char                    *refspec,
+                                           gboolean                       allow_noent,
+                                           OstreeRepoResolveRevExtFlags   flags,
+                                           char                         **out_rev,
+                                           GError                       **error);
+
 _OSTREE_PUBLIC
 gboolean      ostree_repo_list_refs (OstreeRepo       *self,
                                      const char       *refspec_prefix,
@@ -590,7 +611,7 @@ gboolean      ostree_repo_write_archive_to_mtree (OstreeRepo                   *
                                                   GError                      **error);
 
 /**
- * OstreeRepoImportArchiveOptions:
+ * OstreeRepoImportArchiveOptions: (skip)
  *
  * An extensible options structure controlling archive import.  Ensure that
  * you have entirely zeroed the structure, then set just the desired
@@ -608,15 +629,16 @@ typedef struct {
 } OstreeRepoImportArchiveOptions;
 
 _OSTREE_PUBLIC
-gboolean      ostree_repo_import_archive_to_mtree (OstreeRepo                   *self,
+gboolean      ostree_repo_import_archive_to_mtree (OstreeRepo                      *self,
                                                    OstreeRepoImportArchiveOptions  *opts,
-                                                   void                         *archive, /* Really struct archive * */
-                                                   OstreeMutableTree            *mtree,
-                                                   OstreeRepoCommitModifier     *modifier,
-                                                   GCancellable                 *cancellable,
-                                                   GError                      **error);
+                                                   void                            *archive, /* Really struct archive * */
+                                                   OstreeMutableTree               *mtree,
+                                                   OstreeRepoCommitModifier        *modifier,
+                                                    GCancellable                   *cancellable,
+                                                    GError                        **error);
+
 /**
- * OstreeRepoExportArchiveOptions:
+ * OstreeRepoExportArchiveOptions: (skip)
  *
  * An extensible options structure controlling archive creation.  Ensure that
  * you have entirely zeroed the structure, then set just the desired
@@ -700,11 +722,13 @@ typedef enum {
 /**
  * OstreeRepoCheckoutOverwriteMode:
  * @OSTREE_REPO_CHECKOUT_OVERWRITE_NONE: No special options
- * @OSTREE_REPO_CHECKOUT_OVERWRITE_UNION_FILES: When layering checkouts, overwrite earlier files, but keep earlier directories
+ * @OSTREE_REPO_CHECKOUT_OVERWRITE_UNION_FILES: When layering checkouts, unlink() and replace existing files, but do not modify existing directories
+ * @OSTREE_REPO_CHECKOUT_OVERWRITE_ADD_FILES: Only add new files/directories
  */
 typedef enum {
   OSTREE_REPO_CHECKOUT_OVERWRITE_NONE = 0,
-  OSTREE_REPO_CHECKOUT_OVERWRITE_UNION_FILES = 1
+  OSTREE_REPO_CHECKOUT_OVERWRITE_UNION_FILES = 1,
+  OSTREE_REPO_CHECKOUT_OVERWRITE_ADD_FILES = 2, /* Since: 2017.3 */
 } OstreeRepoCheckoutOverwriteMode;
 
 _OSTREE_PUBLIC
@@ -719,30 +743,31 @@ ostree_repo_checkout_tree (OstreeRepo               *self,
                            GError                  **error);
 
 /**
- * OstreeRepoCheckoutOptions:
+ * OstreeRepoCheckoutAtOptions:
  *
  * An extensible options structure controlling checkout.  Ensure that
  * you have entirely zeroed the structure, then set just the desired
- * options.  This is used by ostree_repo_checkout_tree_at() which
+ * options.  This is used by ostree_repo_checkout_at() which
  * supercedes previous separate enumeration usage in
- * ostree_repo_checkout_tree().
+ * ostree_repo_checkout_tree() and ostree_repo_checkout_tree_at().
  */
 typedef struct {
   OstreeRepoCheckoutMode mode;
   OstreeRepoCheckoutOverwriteMode overwrite_mode;
-  
-  guint enable_uncompressed_cache : 1;
-  guint disable_fsync : 1;
-  guint process_whiteouts : 1;
-  guint reserved : 29;
+
+  gboolean enable_uncompressed_cache;  /* Deprecated */
+  gboolean enable_fsync;  /* Deprecated */
+  gboolean process_whiteouts;
+  gboolean no_copy_fallback;
+  gboolean unused_bools[7];
 
   const char *subpath;
 
   OstreeRepoDevInoCache *devino_to_csum_cache;
 
-  guint unused_uints[6];
+  int unused_ints[6];
   gpointer unused_ptrs[7];
-} OstreeRepoCheckoutOptions;
+} OstreeRepoCheckoutAtOptions;
 
 _OSTREE_PUBLIC
 GType ostree_repo_devino_cache_get_type (void);
@@ -754,13 +779,13 @@ _OSTREE_PUBLIC
 void ostree_repo_devino_cache_unref (OstreeRepoDevInoCache *cache);
 
 _OSTREE_PUBLIC
-gboolean ostree_repo_checkout_tree_at (OstreeRepo                         *self,
-                                       OstreeRepoCheckoutOptions          *options,
-                                       int                                 destination_dfd,
-                                       const char                         *destination_path,
-                                       const char                         *commit,
-                                       GCancellable                       *cancellable,
-                                       GError                            **error);
+gboolean ostree_repo_checkout_at (OstreeRepo                         *self,
+                                  OstreeRepoCheckoutAtOptions        *options,
+                                  int                                 destination_dfd,
+                                  const char                         *destination_path,
+                                  const char                         *commit,
+                                  GCancellable                       *cancellable,
+                                  GError                            **error);
 
 _OSTREE_PUBLIC
 gboolean       ostree_repo_checkout_gc (OstreeRepo        *self,
@@ -780,11 +805,13 @@ gboolean       ostree_repo_read_commit (OstreeRepo    *self,
  * @OSTREE_REPO_LIST_OBJECTS_LOOSE: List only loose (plain file) objects
  * @OSTREE_REPO_LIST_OBJECTS_PACKED: List only packed (compacted into blobs) objects
  * @OSTREE_REPO_LIST_OBJECTS_ALL: List all objects
+ * @OSTREE_REPO_LIST_OBJECTS_NO_PARENTS: Only list objects in this repo, not parents
  */
 typedef enum {
   OSTREE_REPO_LIST_OBJECTS_LOOSE = (1 << 0),
   OSTREE_REPO_LIST_OBJECTS_PACKED = (1 << 1),
-  OSTREE_REPO_LIST_OBJECTS_ALL = (1 << 2)
+  OSTREE_REPO_LIST_OBJECTS_ALL = (1 << 2),
+  OSTREE_REPO_LIST_OBJECTS_NO_PARENTS = (1 << 3),
 } OstreeRepoListObjectsFlags;
 
 /**
@@ -866,7 +893,7 @@ gboolean ostree_repo_traverse_commit_union (OstreeRepo         *repo,
 struct _OstreeRepoCommitTraverseIter {
   gboolean initialized;
   gpointer dummy[10];
-  char dummy_checksum_data[65*2];
+  char dummy_checksum_data[(OSTREE_SHA256_STRING_LEN+1)*2];
 };
 
 typedef struct _OstreeRepoCommitTraverseIter OstreeRepoCommitTraverseIter;
@@ -950,6 +977,27 @@ gboolean ostree_repo_prune (OstreeRepo        *self,
                             GCancellable      *cancellable,
                             GError           **error);
 
+struct _OstreeRepoPruneOptions {
+  OstreeRepoPruneFlags flags;
+
+  GHashTable *reachable; /* Set<GVariant> (object names) */
+
+  gboolean unused_bools[6];
+  int unused_ints[6];
+  gpointer unused_ptrs[7];
+};
+
+typedef struct _OstreeRepoPruneOptions OstreeRepoPruneOptions;
+
+_OSTREE_PUBLIC
+gboolean ostree_repo_prune_from_reachable (OstreeRepo             *self,
+                                           OstreeRepoPruneOptions *options,
+                                           gint              *out_objects_total,
+                                           gint              *out_objects_pruned,
+                                           guint64           *out_pruned_object_size_total,
+                                           GCancellable           *cancellable,
+                                           GError              **error);
+
 /**
  * OstreeRepoPullFlags:
  * @OSTREE_REPO_PULL_FLAGS_NONE: No special options for pull
@@ -986,7 +1034,7 @@ ostree_repo_pull_one_dir (OstreeRepo               *self,
 
 _OSTREE_PUBLIC
 gboolean ostree_repo_pull_with_options (OstreeRepo             *self,
-                                        const char             *remote_name,
+                                        const char             *remote_name_or_baseurl,
                                         GVariant               *options,
                                         OstreeAsyncProgress    *progress,
                                         GCancellable           *cancellable,
@@ -1044,6 +1092,14 @@ OstreeGpgVerifyResult * ostree_repo_verify_commit_ext (OstreeRepo    *self,
                                                        GCancellable  *cancellable,
                                                        GError       **error);
 
+_OSTREE_PUBLIC
+OstreeGpgVerifyResult *
+ostree_repo_verify_commit_for_remote (OstreeRepo    *self,
+                                      const gchar   *commit_checksum,
+                                      const gchar   *remote_name,
+                                      GCancellable  *cancellable,
+                                      GError       **error);
+
 _OSTREE_PUBLIC
 OstreeGpgVerifyResult * ostree_repo_gpg_verify_data (OstreeRepo    *self,
                                                      const gchar   *remote_name,
@@ -1070,3 +1126,8 @@ gboolean ostree_repo_regenerate_summary (OstreeRepo     *self,
 
 
 G_END_DECLS
+
+
+/* Include here as the functions defined before should not depend on anything which
+   is defined in -deprecated.h.  */
+#include "ostree-repo-deprecated.h"
